@@ -4,9 +4,8 @@ use strict;
 use warnings;
 use Encode();
 use overload q[""] => '_lat_long';
-use charnames qw(:full);
 
-our $VERSION = '1.67_02';
+our $VERSION = '1.50';
 
 sub _MINUTES_IN_ONE_HOUR             { return 60 }
 sub _MINUTES_IN_ONE_DEGREE           { return 60 }
@@ -47,7 +46,6 @@ sub new {
         altitudeAccuracy => 1,
         speed            => 1,
         timezone_offset  => 1,
-        timezone_name    => 1,
         country_code     => 1,
     );
     foreach my $original ( sort { $a cmp $b } keys %parameters ) {
@@ -72,9 +70,6 @@ sub new {
               $self->_calculate_offset_for_javascript( $1, $2, $3 );
         }
     }
-    if ( defined $parameters{time_zone}{name} ) {
-        $self->{tz} = $parameters{time_zone}{name};
-    }
     if ( defined $self->{country_code} ) {
         if ( $self->{country_code} !~ /^[[:upper:]]{2}$/smx ) {
             delete $self->{country_code};
@@ -136,7 +131,7 @@ sub TO_JSON {
         if ( $key =~ /^(?:$longitude_code|$latitude_code)$/smx ) {
             $json->{location}->{$key} = $self->{$key};
         }
-        elsif ( $key =~ /^(?:accuracy|altitude)$/smx ) {
+        else {
             $json->{$key} = $self->{$key};
         }
     }
@@ -183,11 +178,6 @@ sub timezone_offset {
     return $self->{timezone_offset};
 }
 
-sub tz {
-    my ($self) = @_;
-    return $self->{tz};
-}
-
 sub country_code {
     my ($self) = @_;
     return $self->{country_code};
@@ -212,7 +202,7 @@ Firefox::Marionette::GeoLocation - Represents a GeoLocation for Firefox
 
 =head1 VERSION
 
-Version 1.67_02
+Version 1.50
 
 =head1 SYNOPSIS
 
@@ -241,7 +231,7 @@ returns the accuracy of the altitude expressed in meters.  This value may not be
 
 =head2 country_code
 
-returns the country_code (L<ISO 3166-1 alpha-2|https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2>) of the location.  This value may not be defined.
+returns the country_code (ISO 3166-1 alpha-2) of the location.  This value may not be defined.
 
 =head2 heading
 
@@ -283,7 +273,9 @@ accepts an optional hash as a parameter.  Allowed keys are below;
 
 =item * speed - the velocity of the device in meters per second.
 
-=item * tz - the timezone as an L<Olson TZ identifier|https://en.wikipedia.org/wiki/List_of_tz_database_time_zones#List>.
+=item * timeZone - see timezone_offset.
+
+=item * timezone_offset - the timezone offset in minutes from GMT.
 
 =back
 
@@ -297,10 +289,6 @@ returns the velocity of the device in meters per second.  This value may not be
 
 returns the timezone offset in minutes from GMT.  This value may not be defined.
 
-=head2 tz
-
-returns the timezone as an L<Olson TZ identifier|https://en.wikipedia.org/wiki/List_of_tz_database_time_zones#List>.  This value may not be defined.
-
 =head2 TO_JSON
 
 required to allow L<JSON serialisation|https://metacpan.org/pod/JSON#OBJECT-SERIALISATION> to work correctly.  This method should not need to be called directly.
@@ -335,7 +323,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2024, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2023, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
